import { FileOrFolderPath, FilePath, FolderPath, PathPatternDto } from "@upload-io/upload-shared-iso";
import { FolderPermissionsWithPathAndScope } from "../folders/model/FolderPermissionsWithPathAndScope";
export declare class PathPermissionUtils {
    /**
     * Gets the intersection of all possible effective permissions for all possible paths at the given pattern.
     */
    static getEffectivePermissionsAtPattern<T>(pattern: PathPatternDto, permissionsUnsorted: Array<FolderPermissionsWithPathAndScope<T>>, logicalAnd: (a: T, b: T) => T, logicalFalse: T): T;
    /**
     * From the provided permissions, returns the one that applies to the 'pathToAccess', if any.
     */
    static getEffectivePermissions<T>(pathToAccess: FilePath | FolderPath | FileOrFolderPath, permissionsUnsorted: Array<FolderPermissionsWithPathAndScope<T>>): T | undefined;
    /**
     * Returns all possible effective permissions for every possible path at the given scope.
     */
    private static getEffectivePermissionsAtScope;
    /**
     * Given a path, finds the effective permissions for that path, and returns those permissions and all descendant
     * permissions (i.e. removes irrelevant siblings permissions, and shadowed permissions from ancestors, since when a
     * path is seen, even if it does not have all the scopes, all ancestor permissions are then ignored), and then
     * defaults all missing scopes for all permissions, returning a fully qualified set of permissions for the entire tree.
     */
    private static getFullyQualifiedPermissionsTreeForNearestAncestor;
    private static addMissingScopes;
    private static getAllScopesForPath;
    private static sortPermissions;
    /**
     * Returns the path permissions for the nearest ancestor.
     *
     * All items in the result will have the same 'path'.
     *
     * Intended to mimic 'effectiveFolderSettingsService.getNearestAncestor', so we get consistent behaviour between public
     * folder permissions and API key path permissions. See comment on this class: we always take the nearest ancestor's
     * permissions, even if they won't be effective on the path we're checking, even if a higher ancestor's permissions would.
     */
    private static getNearestPathPermissions;
    private static getNearestPathPermissionsPath;
}
